@@ -16,9 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Ad to GCS operators."""
+from __future__ import annotations
+
 import csv
 from tempfile import NamedTemporaryFile
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.ads.hooks.ads import GoogleAdsHook
@@ -46,15 +48,10 @@ class GoogleAdsListAccountsOperator(BaseOperator):
         :ref:`howto/operator:GoogleAdsListAccountsOperator`
 
     :param bucket: The GCS bucket to upload to
-    :type bucket: str
     :param object_name: GCS path to save the csv file. Must be the full file path (ex. `path/to/file.csv`)
-    :type object_name: str
     :param gcp_conn_id: Airflow Google Cloud connection ID
-    :type gcp_conn_id: str
     :param google_ads_conn_id: Airflow Google Ads connection ID
-    :type google_ads_conn_id: str
     :param gzip: Option to compress local file or file data for upload
-    :type gzip: bool
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -63,9 +60,7 @@ class GoogleAdsListAccountsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     :param api_version: Optional Google Ads API version to use.
-    :type api_version: Optional[str]
     """
 
     template_fields: Sequence[str] = (
@@ -82,8 +77,8 @@ class GoogleAdsListAccountsOperator(BaseOperator):
         gcp_conn_id: str = "google_cloud_default",
         google_ads_conn_id: str = "google_ads_default",
         gzip: bool = False,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
-        api_version: Optional[str] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        api_version: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -95,7 +90,7 @@ class GoogleAdsListAccountsOperator(BaseOperator):
         self.impersonation_chain = impersonation_chain
         self.api_version = api_version
 
-    def execute(self, context: 'Context') -> str:
+    def execute(self, context: Context) -> str:
         uri = f"gs://{self.bucket}/{self.object_name}"
 
         ads_hook = GoogleAdsHook(
