@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Storage Transfer Service Hook."""
+from __future__ import annotations
 
 import json
 import logging
@@ -23,7 +24,7 @@ import time
 import warnings
 from copy import deepcopy
 from datetime import timedelta
-from typing import List, Optional, Sequence, Set, Union
+from typing import Sequence
 
 from googleapiclient.discovery import Resource, build
 from googleapiclient.errors import HttpError
@@ -59,44 +60,44 @@ class GcpTransferOperationStatus:
 ACCESS_KEY_ID = "accessKeyId"
 ALREADY_EXISTING_IN_SINK = "overwriteObjectsAlreadyExistingInSink"
 AWS_ACCESS_KEY = "awsAccessKey"
-AWS_S3_DATA_SOURCE = 'awsS3DataSource'
-BODY = 'body'
-BUCKET_NAME = 'bucketName'
-COUNTERS = 'counters'
-DAY = 'day'
+AWS_S3_DATA_SOURCE = "awsS3DataSource"
+BODY = "body"
+BUCKET_NAME = "bucketName"
+COUNTERS = "counters"
+DAY = "day"
 DESCRIPTION = "description"
-FILTER = 'filter'
-FILTER_JOB_NAMES = 'job_names'
-FILTER_PROJECT_ID = 'project_id'
-GCS_DATA_SINK = 'gcsDataSink'
-GCS_DATA_SOURCE = 'gcsDataSource'
+FILTER = "filter"
+FILTER_JOB_NAMES = "job_names"
+FILTER_PROJECT_ID = "project_id"
+GCS_DATA_SINK = "gcsDataSink"
+GCS_DATA_SOURCE = "gcsDataSource"
 HOURS = "hours"
-HTTP_DATA_SOURCE = 'httpDataSource'
-JOB_NAME = 'name'
-LIST_URL = 'list_url'
-METADATA = 'metadata'
+HTTP_DATA_SOURCE = "httpDataSource"
+JOB_NAME = "name"
+LIST_URL = "list_url"
+METADATA = "metadata"
 MINUTES = "minutes"
-MONTH = 'month'
-NAME = 'name'
-OBJECT_CONDITIONS = 'object_conditions'
-OPERATIONS = 'operations'
-PATH = 'path'
-PROJECT_ID = 'projectId'
-SCHEDULE = 'schedule'
-SCHEDULE_END_DATE = 'scheduleEndDate'
-SCHEDULE_START_DATE = 'scheduleStartDate'
+MONTH = "month"
+NAME = "name"
+OBJECT_CONDITIONS = "object_conditions"
+OPERATIONS = "operations"
+PATH = "path"
+PROJECT_ID = "projectId"
+SCHEDULE = "schedule"
+SCHEDULE_END_DATE = "scheduleEndDate"
+SCHEDULE_START_DATE = "scheduleStartDate"
 SECONDS = "seconds"
 SECRET_ACCESS_KEY = "secretAccessKey"
-START_TIME_OF_DAY = 'startTimeOfDay'
+START_TIME_OF_DAY = "startTimeOfDay"
 STATUS = "status"
-STATUS1 = 'status'
-TRANSFER_JOB = 'transfer_job'
-TRANSFER_JOBS = 'transferJobs'
-TRANSFER_JOB_FIELD_MASK = 'update_transfer_job_field_mask'
-TRANSFER_OPERATIONS = 'transferOperations'
-TRANSFER_OPTIONS = 'transfer_options'
-TRANSFER_SPEC = 'transferSpec'
-YEAR = 'year'
+STATUS1 = "status"
+TRANSFER_JOB = "transfer_job"
+TRANSFER_JOBS = "transferJobs"
+TRANSFER_JOB_FIELD_MASK = "update_transfer_job_field_mask"
+TRANSFER_OPERATIONS = "transferOperations"
+TRANSFER_OPTIONS = "transfer_options"
+TRANSFER_SPEC = "transferSpec"
+YEAR = "year"
 ALREADY_EXIST_CODE = 409
 
 NEGATIVE_STATUSES = {GcpTransferOperationStatus.FAILED, GcpTransferOperationStatus.ABORTED}
@@ -124,11 +125,15 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     def __init__(
         self,
-        api_version: str = 'v1',
+        api_version: str = "v1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
+        if delegate_to:
+            warnings.warn(
+                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
@@ -142,12 +147,11 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         Retrieves connection to Google Storage Transfer service.
 
         :return: Google Storage Transfer service object
-        :rtype: dict
         """
         if not self._conn:
             http_authorized = self._authorize()
             self._conn = build(
-                'storagetransfer', self.api_version, http=http_authorized, cache_discovery=False
+                "storagetransfer", self.api_version, http=http_authorized, cache_discovery=False
             )
         return self._conn
 
@@ -160,11 +164,10 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         :return: transfer job.
             See:
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs#TransferJob
-        :rtype: dict
         """
         body = self._inject_project_id(body, BODY, PROJECT_ID)
-        try:
 
+        try:
             transfer_job = (
                 self.get_conn().transferJobs().create(body=body).execute(num_retries=self.num_retries)
             )
@@ -206,7 +209,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             Job. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
         :return: Transfer Job
-        :rtype: dict
         """
         return (
             self.get_conn()
@@ -215,7 +217,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             .execute(num_retries=self.num_retries)
         )
 
-    def list_transfer_job(self, request_filter: Optional[dict] = None, **kwargs) -> List[dict]:
+    def list_transfer_job(self, request_filter: dict | None = None, **kwargs) -> list[dict]:
         """
         Lists long-running operations in Google Storage Transfer
         Service that match the specified filter.
@@ -223,13 +225,12 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         :param request_filter: (Required) A request filter, as described in
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs/list#body.QUERY_PARAMETERS.filter
         :return: List of Transfer Jobs
-        :rtype: list[dict]
         """
         # To preserve backward compatibility
         # TODO: remove one day
         if request_filter is None:
-            if 'filter' in kwargs:
-                request_filter = kwargs['filter']
+            if "filter" in kwargs:
+                request_filter = kwargs["filter"]
                 if not isinstance(request_filter, dict):
                     raise ValueError(f"The request_filter should be dict and is {type(request_filter)}")
                 warnings.warn("Use 'request_filter' instead of 'filter'", DeprecationWarning)
@@ -239,7 +240,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         conn = self.get_conn()
         request_filter = self._inject_project_id(request_filter, FILTER, FILTER_PROJECT_ID)
         request = conn.transferJobs().list(filter=json.dumps(request_filter))
-        jobs: List[dict] = []
+        jobs: list[dict] = []
 
         while request is not None:
             response = request.execute(num_retries=self.num_retries)
@@ -259,7 +260,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             Job. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
         :return: If successful, TransferJob.
-        :rtype: dict
         """
         return (
             self.get_conn()
@@ -283,7 +283,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         :param body: A request body, as described in
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs/patch#request-body
         :return: If successful, TransferJob.
-        :rtype: dict
         """
         body = self._inject_project_id(body, BODY, PROJECT_ID)
         return (
@@ -305,7 +304,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         :param project_id: (Optional) the ID of the project that owns the Transfer
             Job. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
-        :rtype: None
         """
         (
             self.get_conn()
@@ -326,7 +324,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         Cancels an transfer operation in Google Storage Transfer Service.
 
         :param operation_name: Name of the transfer operation.
-        :rtype: None
         """
         self.get_conn().transferOperations().cancel(name=operation_name).execute(num_retries=self.num_retries)
 
@@ -338,7 +335,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         :return: transfer operation
             See:
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/Operation
-        :rtype: dict
         """
         return (
             self.get_conn()
@@ -347,7 +343,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             .execute(num_retries=self.num_retries)
         )
 
-    def list_transfer_operations(self, request_filter: Optional[dict] = None, **kwargs) -> List[dict]:
+    def list_transfer_operations(self, request_filter: dict | None = None, **kwargs) -> list[dict]:
         """
         Gets an transfer operation in Google Storage Transfer Service.
 
@@ -360,13 +356,12 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
               See: :doc:`/connections/gcp`
 
         :return: transfer operation
-        :rtype: list[dict]
         """
         # To preserve backward compatibility
         # TODO: remove one day
         if request_filter is None:
-            if 'filter' in kwargs:
-                request_filter = kwargs['filter']
+            if "filter" in kwargs:
+                request_filter = kwargs["filter"]
                 if not isinstance(request_filter, dict):
                     raise ValueError(f"The request_filter should be dict and is {type(request_filter)}")
                 warnings.warn("Use 'request_filter' instead of 'filter'", DeprecationWarning)
@@ -379,7 +374,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
         request_filter = self._inject_project_id(request_filter, FILTER, FILTER_PROJECT_ID)
 
-        operations: List[dict] = []
+        operations: list[dict] = []
 
         request = conn.transferOperations().list(name=TRANSFER_OPERATIONS, filter=json.dumps(request_filter))
 
@@ -399,7 +394,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         Pauses an transfer operation in Google Storage Transfer Service.
 
         :param operation_name: (Required) Name of the transfer operation.
-        :rtype: None
         """
         self.get_conn().transferOperations().pause(name=operation_name).execute(num_retries=self.num_retries)
 
@@ -408,15 +402,14 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         Resumes an transfer operation in Google Storage Transfer Service.
 
         :param operation_name: (Required) Name of the transfer operation.
-        :rtype: None
         """
         self.get_conn().transferOperations().resume(name=operation_name).execute(num_retries=self.num_retries)
 
     def wait_for_transfer_job(
         self,
         job: dict,
-        expected_statuses: Optional[Set[str]] = None,
-        timeout: Optional[Union[float, timedelta]] = None,
+        expected_statuses: set[str] | None = None,
+        timeout: float | timedelta | None = None,
     ) -> None:
         """
         Waits until the job reaches the expected state.
@@ -429,7 +422,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferOperations#Status
         :param timeout: Time in which the operation must end in seconds. If not specified, defaults to 60
             seconds.
-        :rtype: None
         """
         expected_statuses = (
             {GcpTransferOperationStatus.SUCCESS} if not expected_statuses else expected_statuses
@@ -464,7 +456,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     @staticmethod
     def operations_contain_expected_statuses(
-        operations: List[dict], expected_statuses: Union[Set[str], str]
+        operations: list[dict], expected_statuses: set[str] | str
     ) -> bool:
         """
         Checks whether the operation list has an operation with the
@@ -480,7 +472,6 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             in the operation list, returns true,
         :raises: airflow.exceptions.AirflowException If it encounters operations
             with a state in the list,
-        :rtype: bool
         """
         expected_statuses_set = (
             {expected_statuses} if isinstance(expected_statuses, str) else set(expected_statuses)
@@ -495,8 +486,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
         if len(NEGATIVE_STATUSES - current_statuses) != len(NEGATIVE_STATUSES):
             raise AirflowException(
-                'An unexpected operation status was encountered. Expected: {}'.format(
-                    ", ".join(expected_statuses_set)
-                )
+                f"An unexpected operation status was encountered. "
+                f"Expected: {', '.join(expected_statuses_set)}"
             )
         return False
