@@ -32,9 +32,9 @@ from google.cloud.bigquery_datatransfer_v1 import (
 
 from airflow import AirflowException
 from airflow.compat.functools import cached_property
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigquery_dts import BiqQueryDataTransferServiceHook, get_object_id
 from airflow.providers.google.cloud.links.bigquery_dts import BigQueryDataTransferConfigLink
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.cloud.triggers.bigquery_dts import BigQueryDataTransferRunTrigger
 
 if TYPE_CHECKING:
@@ -46,7 +46,7 @@ def _get_transfer_config_details(config_transfer_name: str):
     return {"project_id": config_details[1], "region": config_details[3], "config_id": config_details[5]}
 
 
-class BigQueryCreateDataTransferOperator(BaseOperator):
+class BigQueryCreateDataTransferOperator(GoogleCloudBaseOperator):
     """
     Creates a new data transfer configuration.
 
@@ -138,10 +138,13 @@ class BigQueryCreateDataTransferOperator(BaseOperator):
         result = TransferConfig.to_dict(response)
         self.log.info("Created DTS transfer config %s", get_object_id(result))
         self.xcom_push(context, key="transfer_config_id", value=get_object_id(result))
+        # don't push AWS secret in XCOM
+        result.get("params", {}).pop("secret_access_key", None)
+        result.get("params", {}).pop("access_key_id", None)
         return result
 
 
-class BigQueryDeleteDataTransferConfigOperator(BaseOperator):
+class BigQueryDeleteDataTransferConfigOperator(GoogleCloudBaseOperator):
     """
     Deletes transfer configuration.
 
@@ -213,7 +216,7 @@ class BigQueryDeleteDataTransferConfigOperator(BaseOperator):
         )
 
 
-class BigQueryDataTransferServiceStartTransferRunsOperator(BaseOperator):
+class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperator):
     """
     Start manual transfer runs to be executed now with schedule_time equal
     to current time. The transfer runs can be created for a time range where
