@@ -16,11 +16,13 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Vision operator."""
+from __future__ import annotations
 
 from copy import deepcopy
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING, Any, Sequence, Tuple
 
 from google.api_core.exceptions import AlreadyExists
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.vision_v1.types import (
     AnnotateImageRequest,
@@ -31,8 +33,8 @@ from google.cloud.vision_v1.types import (
     ReferenceImage,
 )
 
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.vision import CloudVisionHook
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -41,7 +43,7 @@ if TYPE_CHECKING:
 MetaData = Sequence[Tuple[str, str]]
 
 
-class CloudVisionCreateProductSetOperator(BaseOperator):
+class CloudVisionCreateProductSetOperator(GoogleCloudBaseOperator):
     """
     Creates a new ProductSet resource.
 
@@ -89,15 +91,15 @@ class CloudVisionCreateProductSetOperator(BaseOperator):
     def __init__(
         self,
         *,
-        product_set: Union[dict, ProductSet],
+        product_set: dict | ProductSet,
         location: str,
-        project_id: Optional[str] = None,
-        product_set_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        product_set_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -111,7 +113,7 @@ class CloudVisionCreateProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -134,7 +136,7 @@ class CloudVisionCreateProductSetOperator(BaseOperator):
             return self.product_set_id
 
 
-class CloudVisionGetProductSetOperator(BaseOperator):
+class CloudVisionGetProductSetOperator(GoogleCloudBaseOperator):
     """
     Gets information associated with a ProductSet.
 
@@ -166,11 +168,11 @@ class CloudVisionGetProductSetOperator(BaseOperator):
 
     # [START vision_productset_get_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_set_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_set_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_productset_get_template_fields]
 
@@ -179,12 +181,12 @@ class CloudVisionGetProductSetOperator(BaseOperator):
         *,
         location: str,
         product_set_id: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -197,7 +199,7 @@ class CloudVisionGetProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -212,7 +214,7 @@ class CloudVisionGetProductSetOperator(BaseOperator):
         )
 
 
-class CloudVisionUpdateProductSetOperator(BaseOperator):
+class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
     """
     Makes changes to a `ProductSet` resource. Only display_name can be updated currently.
 
@@ -240,7 +242,7 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
     :param project_id: (Optional) The project in which the ProductSet should be created. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
     :param update_mask: (Optional) The `FieldMask` that specifies which fields to update. If update_mask
-        isn’t specified, all mutable fields are to be updated. Valid mask path is display_name. If a dict is
+        isn't specified, all mutable fields are to be updated. Valid mask path is display_name. If a dict is
         provided, it must be of the same form as the protobuf message `FieldMask`.
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
@@ -261,27 +263,27 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
 
     # [START vision_productset_update_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_set_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_set_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_productset_update_template_fields]
 
     def __init__(
         self,
         *,
-        product_set: Union[Dict, ProductSet],
-        location: Optional[str] = None,
-        product_set_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        update_mask: Union[Dict, FieldMask] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        product_set: dict | ProductSet,
+        location: str | None = None,
+        product_set_id: str | None = None,
+        project_id: str | None = None,
+        update_mask: dict | FieldMask = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -296,7 +298,7 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -313,7 +315,7 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
         )
 
 
-class CloudVisionDeleteProductSetOperator(BaseOperator):
+class CloudVisionDeleteProductSetOperator(GoogleCloudBaseOperator):
     """
     Permanently deletes a `ProductSet`. `Products` and `ReferenceImages` in the
     `ProductSet` are not deleted. The actual image files are not deleted from Google
@@ -347,11 +349,11 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
 
     # [START vision_productset_delete_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_set_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_set_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_productset_delete_template_fields]
 
@@ -360,12 +362,12 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
         *,
         location: str,
         product_set_id: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -378,7 +380,7 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -393,7 +395,7 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
         )
 
 
-class CloudVisionCreateProductOperator(BaseOperator):
+class CloudVisionCreateProductOperator(GoogleCloudBaseOperator):
     """
     Creates and returns a new product resource.
 
@@ -436,11 +438,11 @@ class CloudVisionCreateProductOperator(BaseOperator):
 
     # [START vision_product_create_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_create_template_fields]
 
@@ -449,13 +451,13 @@ class CloudVisionCreateProductOperator(BaseOperator):
         *,
         location: str,
         product: str,
-        project_id: Optional[str] = None,
-        product_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        product_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -469,7 +471,7 @@ class CloudVisionCreateProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -486,12 +488,12 @@ class CloudVisionCreateProductOperator(BaseOperator):
             )
         except AlreadyExists:
             self.log.info(
-                'Product with id %s already exists. Exiting from the create operation.', self.product_id
+                "Product with id %s already exists. Exiting from the create operation.", self.product_id
             )
             return self.product_id
 
 
-class CloudVisionGetProductOperator(BaseOperator):
+class CloudVisionGetProductOperator(GoogleCloudBaseOperator):
     """
     Gets information associated with a `Product`.
 
@@ -527,11 +529,11 @@ class CloudVisionGetProductOperator(BaseOperator):
 
     # [START vision_product_get_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_get_template_fields]
 
@@ -540,12 +542,12 @@ class CloudVisionGetProductOperator(BaseOperator):
         *,
         location: str,
         product_id: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -558,7 +560,7 @@ class CloudVisionGetProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -573,7 +575,7 @@ class CloudVisionGetProductOperator(BaseOperator):
         )
 
 
-class CloudVisionUpdateProductOperator(BaseOperator):
+class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
     """
     Makes changes to a Product resource. Only the display_name, description, and labels fields can be
     updated right now.
@@ -611,7 +613,7 @@ class CloudVisionUpdateProductOperator(BaseOperator):
     :param project_id: (Optional) The project in which the Product is located. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
     :param update_mask: (Optional) The `FieldMask` that specifies which fields to update. If update_mask
-        isn’t specified, all mutable fields are to be updated. Valid mask paths include product_labels,
+        isn't specified, all mutable fields are to be updated. Valid mask paths include product_labels,
         display_name, and description. If a dict is provided, it must be of the same form as the protobuf
         message `FieldMask`.
     :param retry: (Optional) A retry object used to retry requests. If `None` is
@@ -633,27 +635,27 @@ class CloudVisionUpdateProductOperator(BaseOperator):
 
     # [START vision_product_update_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_update_template_fields]
 
     def __init__(
         self,
         *,
-        product: Union[Dict, Product],
-        location: Optional[str] = None,
-        product_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        update_mask: Union[Dict, FieldMask] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        product: dict | Product,
+        location: str | None = None,
+        product_id: str | None = None,
+        project_id: str | None = None,
+        update_mask: dict | FieldMask = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -668,7 +670,7 @@ class CloudVisionUpdateProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -685,7 +687,7 @@ class CloudVisionUpdateProductOperator(BaseOperator):
         )
 
 
-class CloudVisionDeleteProductOperator(BaseOperator):
+class CloudVisionDeleteProductOperator(GoogleCloudBaseOperator):
     """
     Permanently deletes a product and its reference images.
 
@@ -724,11 +726,11 @@ class CloudVisionDeleteProductOperator(BaseOperator):
 
     # [START vision_product_delete_template_fields]
     template_fields: Sequence[str] = (
-        'location',
-        'project_id',
-        'product_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "location",
+        "project_id",
+        "product_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_product_delete_template_fields]
 
@@ -737,12 +739,12 @@ class CloudVisionDeleteProductOperator(BaseOperator):
         *,
         location: str,
         product_id: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -755,7 +757,7 @@ class CloudVisionDeleteProductOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -770,7 +772,7 @@ class CloudVisionDeleteProductOperator(BaseOperator):
         )
 
 
-class CloudVisionImageAnnotateOperator(BaseOperator):
+class CloudVisionImageAnnotateOperator(GoogleCloudBaseOperator):
     """
     Run image detection and annotation for an image or a batch of images.
 
@@ -799,20 +801,20 @@ class CloudVisionImageAnnotateOperator(BaseOperator):
 
     # [START vision_annotate_image_template_fields]
     template_fields: Sequence[str] = (
-        'request',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "request",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END vision_annotate_image_template_fields]
 
     def __init__(
         self,
         *,
-        request: Union[Dict, AnnotateImageRequest],
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        request: dict | AnnotateImageRequest,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -822,7 +824,7 @@ class CloudVisionImageAnnotateOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -838,7 +840,7 @@ class CloudVisionImageAnnotateOperator(BaseOperator):
         return response
 
 
-class CloudVisionCreateReferenceImageOperator(BaseOperator):
+class CloudVisionCreateReferenceImageOperator(GoogleCloudBaseOperator):
     """
     Creates and returns a new ReferenceImage ID resource.
 
@@ -892,15 +894,15 @@ class CloudVisionCreateReferenceImageOperator(BaseOperator):
         self,
         *,
         location: str,
-        reference_image: Union[Dict, ReferenceImage],
+        reference_image: dict | ReferenceImage,
         product_id: str,
-        reference_image_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        reference_image_id: str | None = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -915,7 +917,7 @@ class CloudVisionCreateReferenceImageOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         try:
             hook = CloudVisionHook(
                 gcp_conn_id=self.gcp_conn_id,
@@ -939,7 +941,7 @@ class CloudVisionCreateReferenceImageOperator(BaseOperator):
             return self.reference_image_id
 
 
-class CloudVisionDeleteReferenceImageOperator(BaseOperator):
+class CloudVisionDeleteReferenceImageOperator(GoogleCloudBaseOperator):
     """
     Deletes a ReferenceImage ID resource.
 
@@ -990,12 +992,12 @@ class CloudVisionDeleteReferenceImageOperator(BaseOperator):
         location: str,
         product_id: str,
         reference_image_id: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
-        gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        gcp_conn_id: str = "google_cloud_default",
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1009,7 +1011,7 @@ class CloudVisionDeleteReferenceImageOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1025,7 +1027,7 @@ class CloudVisionDeleteReferenceImageOperator(BaseOperator):
         )
 
 
-class CloudVisionAddProductToProductSetOperator(BaseOperator):
+class CloudVisionAddProductToProductSetOperator(GoogleCloudBaseOperator):
     """
     Adds a Product to the specified ProductSet. If the Product is already present, no change is made.
 
@@ -1033,7 +1035,7 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
 
     Possible errors:
 
-    - Returns `NOT_FOUND` if the Product or the ProductSet doesn’t exist.
+    - Returns `NOT_FOUND` if the Product or the ProductSet doesn't exist.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1079,12 +1081,12 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
         product_set_id: str,
         product_id: str,
         location: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1098,7 +1100,7 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1114,7 +1116,7 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
         )
 
 
-class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
+class CloudVisionRemoveProductFromProductSetOperator(GoogleCloudBaseOperator):
     """
     Removes a Product from the specified ProductSet.
 
@@ -1162,12 +1164,12 @@ class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
         product_set_id: str,
         product_id: str,
         location: str,
-        project_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        project_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
         metadata: MetaData = (),
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1181,7 +1183,7 @@ class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1197,7 +1199,7 @@ class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
         )
 
 
-class CloudVisionDetectTextOperator(BaseOperator):
+class CloudVisionDetectTextOperator(GoogleCloudBaseOperator):
     """
     Detects Text in the image
 
@@ -1240,15 +1242,15 @@ class CloudVisionDetectTextOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        language_hints: Optional[Union[str, List[str]]] = None,
-        web_detection_params: Optional[Dict] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        language_hints: str | list[str] | None = None,
+        web_detection_params: dict | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1265,7 +1267,7 @@ class CloudVisionDetectTextOperator(BaseOperator):
         )
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1279,7 +1281,7 @@ class CloudVisionDetectTextOperator(BaseOperator):
         )
 
 
-class CloudVisionTextDetectOperator(BaseOperator):
+class CloudVisionTextDetectOperator(GoogleCloudBaseOperator):
     """
     Detects Document Text in the image
 
@@ -1322,15 +1324,15 @@ class CloudVisionTextDetectOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        language_hints: Optional[Union[str, List[str]]] = None,
-        web_detection_params: Optional[Dict] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        language_hints: str | list[str] | None = None,
+        web_detection_params: dict | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1346,7 +1348,7 @@ class CloudVisionTextDetectOperator(BaseOperator):
         )
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1360,7 +1362,7 @@ class CloudVisionTextDetectOperator(BaseOperator):
         )
 
 
-class CloudVisionDetectImageLabelsOperator(BaseOperator):
+class CloudVisionDetectImageLabelsOperator(GoogleCloudBaseOperator):
     """
     Detects Document Text in the image
 
@@ -1399,13 +1401,13 @@ class CloudVisionDetectImageLabelsOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1417,7 +1419,7 @@ class CloudVisionDetectImageLabelsOperator(BaseOperator):
         self.additional_properties = additional_properties
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1431,7 +1433,7 @@ class CloudVisionDetectImageLabelsOperator(BaseOperator):
         )
 
 
-class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
+class CloudVisionDetectImageSafeSearchOperator(GoogleCloudBaseOperator):
     """
     Detects Document Text in the image
 
@@ -1470,13 +1472,13 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
 
     def __init__(
         self,
-        image: Union[Dict, Image],
-        max_results: Optional[int] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        additional_properties: Optional[Dict] = None,
+        image: dict | Image,
+        max_results: int | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        additional_properties: dict | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -1488,7 +1490,7 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
         self.additional_properties = additional_properties
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = CloudVisionHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -1503,8 +1505,8 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
 
 
 def prepare_additional_parameters(
-    additional_properties: Optional[Dict], language_hints: Any, web_detection_params: Any
-) -> Optional[Dict]:
+    additional_properties: dict | None, language_hints: Any, web_detection_params: Any
+) -> dict | None:
     """
     Creates additional_properties parameter based on language_hints, web_detection_params and
     additional_properties parameters specified by the user
@@ -1517,14 +1519,14 @@ def prepare_additional_parameters(
 
     merged_additional_parameters = deepcopy(additional_properties)
 
-    if 'image_context' not in merged_additional_parameters:
-        merged_additional_parameters['image_context'] = {}
+    if "image_context" not in merged_additional_parameters:
+        merged_additional_parameters["image_context"] = {}
 
-    merged_additional_parameters['image_context']['language_hints'] = merged_additional_parameters[
-        'image_context'
-    ].get('language_hints', language_hints)
-    merged_additional_parameters['image_context']['web_detection_params'] = merged_additional_parameters[
-        'image_context'
-    ].get('web_detection_params', web_detection_params)
+    merged_additional_parameters["image_context"]["language_hints"] = merged_additional_parameters[
+        "image_context"
+    ].get("language_hints", language_hints)
+    merged_additional_parameters["image_context"]["web_detection_params"] = merged_additional_parameters[
+        "image_context"
+    ].get("web_detection_params", web_detection_params)
 
     return merged_additional_parameters
